@@ -28,7 +28,9 @@
 #' \item \code{sample_strata}: Uses the \code{data} from the previous wave
 #' (or previous phase if \code{wave = 1}) and \code{design}
 #' from current wave to generate a vector of ids to sample for the current
-#' wave. If used, the output multiwave object contains an updated
+#' wave. Note that the \code{wave} argument of the standalone
+#' \code{sample_strata()} function does not apply here,
+#'  If used, the output multiwave object contains an updated
 #' \code{"samples"} slot in the specified wave.
 #' \item \code{merge_samples}: Uses the \code{data} from the previous wave (or
 #' previous phase if \code{wave = 1}) and \code{sampled_data} from the
@@ -60,8 +62,8 @@
 #'
 #' library(datasets)
 #'
-#' MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-#' get_data(MySurvey, phase = 1, slot = "data") <-
+#' MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+#' set_mw(MySurvey, phase = 1, slot = "data") <-
 #'   dplyr::select(datasets::iris, -Sepal.Width)
 #'
 #' # Get Design by applying optimum_allocation
@@ -74,7 +76,7 @@
 #' )
 #'
 #' # or, we can establish function args in the metadata
-#' get_data(MySurvey, phase = 2, slot = "metadata") <- list(
+#' set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
 #'   strata = "Species",
 #'   nsample = 15,
 #'   y = "Sepal.Length",
@@ -86,7 +88,7 @@
 #'   phase = 2, wave = 1,
 #'   fun = "optimum_allocation"
 #' )
-#' @include get_data.R phase.R wave.R multiwave.R optimum_allocation.R
+#' @include get_mw.R set_mw.R phase.R wave.R multiwave.R optimum_allocation.R
 #' @include allocate_wave.R merge_samples.R sample_strata.R
 #' @importFrom magrittr %>%
 #' @export
@@ -488,6 +490,29 @@ setMethod(
          'design' slot of the specified wave.")
       }
 
+      # Probs
+      if (is.null(arguments$probs)) {
+        if ("probs" %in% names(wave_md) &
+            inherits(wave_md$probs, "character")) {
+          probs <- wave_md$probs
+        } else if ("probs" %in% names(phase_md) &
+                   inherits(phase_md$probs, "character")) {
+          probs <- phase_md$probs
+        } else if ("probs" %in% names(survey_md) &
+                   inherits(survey_md$probs, "character")) {
+          probs <- survey_md$probs
+        } else {
+          probs <- NULL
+        }
+      } else if (is.character(arguments$probs)) {
+        if(!(arguments$probs %in% names(design_data))){
+            stop("'probs' must be a formula or column name of the 'design_data'
+            slot of the specified wave")
+        }
+      }
+      probs <- arguments$probs
+
+
 
       # Now id
       if (is.null(arguments$id)) {
@@ -562,18 +587,30 @@ setMethod(
         'design' slot of the specified wave.")
       }
 
+
       output <- sample_strata(
         data = data, id = id,
         strata = strata, already_sampled = already_sampled,
         design_data = design_data,
         design_strata = design_strata,
-        n_allocated = n_allocated
+        n_allocated = n_allocated,
+        probs = probs,
+        wave = NULL,
+        warn_prob_overwrite = FALSE
       )
 
       x_updated <- x
       sample_indicator <- NULL
-      x_updated@phases[[phase]]@waves[[wave]]@samples <-
-        as.character(dplyr::filter(output, sample_indicator == 1)$id)
+      samps <- dplyr::filter(output, sample_indicator == 1)
+      x_updated@phases[[phase]]@waves[[wave]]@samples$ids <-
+        samps$id
+      if(!(is.null(probs))){
+        x_updated@phases[[phase]]@waves[[wave]]@samples$probs <-
+        samps$sampling_prob
+      } else{
+        x_updated@phases[[phase]]@waves[[wave]]@samples$probs <- c()
+      } # To ensure incorrect/old probs are removed
+
       return(x_updated)
     }
 
@@ -599,27 +636,61 @@ setMethod(
         id <- arguments$id
       }
 
-      if (is.null(arguments$sampled_ind)) {
-        if ("sampled_ind" %in% names(wave_md) &
-            inherits(wave_md$sampled_ind, "character")) {
-          sampled_ind <- wave_md$sampled_ind
-        } else if ("sampled_ind" %in% names(phase_md) &
-            inherits(phase_md$sampled_ind, "character")) {
-          sampled_ind <- phase_md$sampled_ind
-        } else if ("sampled_ind" %in% names(survey_md) &
-            inherits(survey_md$sampled_ind, "character")) {
-          sampled_ind <- survey_md$sampled_ind
+      if (is.null(arguments$phase_sample_ind)) {
+        if ("phase_sample_ind" %in% names(wave_md) &
+            inherits(wave_md$phase_sample_ind, "character")) {
+          phase_sample_ind <- wave_md$phase_sample_ind
+        } else if ("phase_sample_ind" %in% names(phase_md) &
+            inherits(phase_md$phase_sample_ind, "character")) {
+          phase_sample_ind <- phase_md$phase_sample_ind
+        } else if ("phase_sample_ind" %in% names(survey_md) &
+            inherits(survey_md$phase_sample_ind, "character")) {
+          phase_sample_ind <- survey_md$phase_sample_ind
         } else {
-          sampled_ind <- "sampled_ind"
+          phase_sample_ind <- "phase_sample_ind"
         }
       } else {
-        sampled_ind <- arguments$sampled_ind
+        phase_sample_ind <- arguments$phase_sample_ind
       }
 
+      if (is.null(arguments$wave_sample_ind)) {
+        if ("wave_sample_ind" %in% names(wave_md) &
+            inherits(wave_md$wave_sample_ind, "character")) {
+          wave_sample_ind <- wave_md$wave_sample_ind
+        } else if ("wave_sample_ind" %in% names(phase_md) &
+                   inherits(phase_md$wave_sample_ind, "character")) {
+          wave_sample_ind <- phase_md$wave_sample_ind
+        } else if ("wave_sample_ind" %in% names(survey_md) &
+                   inherits(survey_md$wave_sample_ind, "character")) {
+          wave_sample_ind <- survey_md$wave_sample_ind
+        } else {
+          wave_sample_ind <- "wave_sample_ind"
+        }
+      } else {
+        wave_sample_ind <- arguments$wave_sample_ind
+      }
+
+      # Get include_probs if given include_probs is NULL
+      if(is.null(arguments$include_probs)){
+        if ("include_probs" %in% names(wave_md)){
+          include_probs <- wave_md$include_probs
+        } else if ("include_probs" %in% names(phase_md)) {
+          include_probs <- phase_md$include_probs
+        } else if ("include_probs" %in% names(survey_md)) {
+          include_probs <- survey_md$include_probs
+        } else{
+          include_probs <- FALSE
+        }
+      } else{
+        include_probs <- arguments$include_probs
+        }
+
 
       x_updated <- merge_samples(
         x = x, phase = phase, wave = wave, id = id,
-        sampled_ind = sampled_ind
+        phase_sample_ind = phase_sample_ind,
+        wave_sample_ind = wave_sample_ind,
+        include_probs = include_probs
       )
       return(x_updated)
     }
